/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http//www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is ART Ontology API (Sesame2 Implementation).
 *
 * The Initial Developer of the Original Code is University of Roma Tor Vergata.
 * Portions created by University of Roma Tor Vergata are Copyright (C) 2007.
 * All Rights Reserved.
 *
 * ART Ontology API (Sesame2 Implementation) was developed by the Artificial Intelligence Research Group
 * (art.uniroma2.it) at the University of Roma Tor Vergata
 * Current information about the ART Ontology API (Sesame2 Implementation) can be obtained at 
 * http//art.uniroma2.it/owlart
 *
 */
package it.uniroma2.art.owlart.sesame2impl.models;

import it.uniroma2.art.owlart.exceptions.ModelAccessException;
import it.uniroma2.art.owlart.exceptions.VocabularyInitializationException;
import it.uniroma2.art.owlart.model.ARTResource;
import it.uniroma2.art.owlart.model.ARTURIResource;
import it.uniroma2.art.owlart.models.DirectReasoning;
import it.uniroma2.art.owlart.models.impl.ObjectsOfStatementsIterator;
import it.uniroma2.art.owlart.models.impl.RDFSModelImpl;
import it.uniroma2.art.owlart.models.impl.ResourceIteratorWrappingNodeIterator;
import it.uniroma2.art.owlart.models.impl.SubjectsOfStatementsIterator;
import it.uniroma2.art.owlart.models.impl.URIResourceIteratorWrappingNodeIterator;
import it.uniroma2.art.owlart.models.impl.URIResourceIteratorWrappingResourceIterator;
import it.uniroma2.art.owlart.navigation.ARTResourceIterator;
import it.uniroma2.art.owlart.navigation.ARTURIResourceIterator;
import it.uniroma2.art.owlart.sesame2impl.vocabulary.SESAME;

public class RDFSModelSesame2Impl extends RDFSModelImpl implements DirectReasoning {
    
	public RDFSModelSesame2Impl(BaseRDFModelSesame2Impl baseRep) throws VocabularyInitializationException {
		super(baseRep);
        SESAME.Res.initialize(this);
	}

	public ARTResourceIterator listDirectInstances(ARTResource type, ARTResource... contexts) throws ModelAccessException {
		return new SubjectsOfStatementsIterator(listStatements(null, SESAME.Res.DIRECTTYPE, type, true, contexts));
	}

	public ARTResourceIterator listDirectTypes(ARTResource res, ARTResource... contexts) throws ModelAccessException {
		return new ResourceIteratorWrappingNodeIterator( new ObjectsOfStatementsIterator(listStatements(res, SESAME.Res.DIRECTTYPE, null, true, contexts)) );
	}

	public ARTResourceIterator listDirectSuperClasses(ARTResource resource, ARTResource... contexts) throws ModelAccessException {
		return new ResourceIteratorWrappingNodeIterator( new ObjectsOfStatementsIterator(listStatements(resource, SESAME.Res.DIRECTSUBCLASSOF, null, true, contexts)) );
	}

	public ARTURIResourceIterator listDirectSuperProperties(ARTResource resource, ARTResource... contexts) throws ModelAccessException {
		return new URIResourceIteratorWrappingNodeIterator( new ObjectsOfStatementsIterator(listStatements(resource, SESAME.Res.DIRECTSUBPROPERTYOF, null, true, contexts)) );
	}
	
	public ARTResourceIterator listDirectSubClasses(ARTResource resource, ARTResource... contexts) throws ModelAccessException {
		return new SubjectsOfStatementsIterator(listStatements(null, SESAME.Res.DIRECTSUBCLASSOF, resource, true, contexts));
	}
	
	public ARTURIResourceIterator listDirectSubProperties (ARTURIResource resource, ARTResource... contexts) throws ModelAccessException {
		return new URIResourceIteratorWrappingResourceIterator( new SubjectsOfStatementsIterator(listStatements(null, SESAME.Res.DIRECTSUBPROPERTYOF, resource, true, contexts)) );
	}

	
}
